@@ -1,5 +1,6 @@
 package Cvs::Result::Commit;
 
+
 use strict;
 use base qw(Cvs::Result::Base);
 
@@ -10,11 +11,20 @@ use base qw(Cvs::Result::Base);
 
 Cvs::Result::Commit - Result class for cvs commit command
 
+=head1 SYNOPSIS
+
+  my $commit = $cvs->commit
+    ( { recursive => 0, message => 'bar', },
+      'changed.txt' );
+
+  my $old = $commit->old_revision;
+  my $new = $commit->new_revision;
+
 =head1 DESCRIPTION
 
-This class handles things that compose the result of the commit command.
+Returns the old and new revisions of a previously checked-in file.
 
-=head1 FIELDS
+=head1 METHODS
 
 =head2 old_revision
 
@@ -45,6 +55,14 @@ sub set_revision
 1;
 =pod
 
+=head1 SEE ALSO
+
+L<Cvs::Command::Commit>, L<Cvs>, cvs(1).
+
+=head1 AUTHOR
+
+Steven Cotton E<lt>cotton@cpan.orgE<gt>
+
 =head1 LICENCE
 
 This library is free software; you can redistribute it and/or modify
